@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /*
  * gelide
- * Copyright (C) 2008 Juan Ángel Moreno Fernández
+ * Copyright (C) 2008 - 2011 Juan Ángel Moreno Fernández
  *
  * gelide is free software.
  *
@@ -24,8 +24,8 @@
 #include <glib/gstdio.h>
 #include <sstream>
 #include "system.hpp"
-#include "cmprodatfile.hpp"
-#include "../gelide-utils.hpp"
+#include "../utils/tokenizer.hpp"
+
 
 
 CSystem::CSystem(void){
@@ -42,7 +42,7 @@ CSystem::CSystem(void){
 	m_tittle_dir = "";
 	m_front_dir = "";
 	m_back_dir = "";
-	m_card_dir = "";
+	m_media_dir = "";
 	m_emulator_id = 0;
 
 	m_dat_name = "";
@@ -80,7 +80,7 @@ CSystem& CSystem::operator=(CSystem& p_system){
 		this->setTitleDir(p_system.getTitleDir());
 		this->setFrontDir(p_system.getFrontDir());
 		this->setBackDir(p_system.getBackDir());
-		this->setCardDir(p_system.getCardDir());
+		this->setMediaDir(p_system.getMediaDir());
 		this->setEmulatorId(p_system.getEmulatorId());
 		this->setDatName(p_system.getDatName());
 		this->setDatDescription(p_system.getDatDescription());
@@ -94,7 +94,7 @@ CSystem& CSystem::operator=(CSystem& p_system){
 
 bool CSystem::load(void){
 	CTokenizer l_tokenizer;
-	CToken l_token;
+	CTokenizer::CToken l_token;
 	Gtk::TreeModel::iterator l_iter;
 	CEmulator l_emulator;
 	int l_ind;
@@ -108,7 +108,8 @@ bool CSystem::load(void){
 	GELIDE_DEBUG("System " << getName().data() << ": Loading games...");
 	// Iniciamos la carga
 	if(l_tokenizer.initFromFile(m_home_dir + "/" + SYSTEMS_GAMES_LIST)){
-		l_tokenizer.setDelimiters((char *)CSV_SEPARATOR, 1);
+		//l_tokenizer.setDelimiters((char *)CSV_SEPARATOR, 1);
+		l_tokenizer.setDelimiters("\n\x3B", 2);
 		while(l_tokenizer.hasMoreTokens()){
 			l_iter = m_game_list->append();
 
@@ -138,7 +139,8 @@ bool CSystem::load(void){
 	GELIDE_DEBUG("System " << getName().data() << ": Loading emulators...");
 	// Iniciamos la carga
 	if(l_tokenizer.initFromFile(m_home_dir + "/" + SYSTEMS_EMULATORS_LIST)){
-		l_tokenizer.setDelimiters((char *)CSV_SEPARATOR, 1);
+		//l_tokenizer.setDelimiters((char *)CSV_SEPARATOR, 1);
+		l_tokenizer.setDelimiters("\n\x3B", 2);
 		while(l_tokenizer.hasMoreTokens()){
 			l_tokenizer.nextToken(l_token);
 			l_emulator.setId(l_token.getValue());
@@ -259,7 +261,7 @@ Glib::ustring CSystem::getAsString(void){
 	std::stringstream l_str;
 	/*
 	 id;"name";"description";"icon_file";"dat_file";"bios_file";"home_dir";""rom_dir";
-	"snap_dir";"tittle_dir";"front_dir";"back_dir";"card_dir";emulator_id;
+	"snap_dir";"tittle_dir";"front_dir";"back_dir";"media_dir";emulator_id;
 	"datname";"datDescription";"datcategory";datversion";"datauthor";datgames;
 	*/
 
@@ -275,7 +277,7 @@ Glib::ustring CSystem::getAsString(void){
 		<< "\"" << Glib::strescape(getTitleDir()) << "\"" << CSV_SEPARATOR
 		<< "\"" << Glib::strescape(getFrontDir()) << "\"" << CSV_SEPARATOR
 		<< "\"" << Glib::strescape(getBackDir()) << "\"" << CSV_SEPARATOR
-		<< "\"" << Glib::strescape(getCardDir()) << "\"" << CSV_SEPARATOR
+		<< "\"" << Glib::strescape(getMediaDir()) << "\"" << CSV_SEPARATOR
 		<< getEmulatorId() << CSV_SEPARATOR
 		<< "\"" << Glib::strescape(getDatName()) << "\"" << CSV_SEPARATOR
 		<< "\"" << Glib::strescape(getDatDescription()) << "\"" << CSV_SEPARATOR
@@ -393,26 +395,18 @@ Gtk::TreeModel::iterator CSystem::addEmulator(CEmulator& p_emulator){
 	Gtk::TreeModel::iterator l_iter;
 	int l_id;
 
-	// Comprobamos si es un emulador nuevo (Id = 0)
-	if(p_emulator.getId() == 0){
-		// Generamos el id como uno más que el último
-		if(m_emulator_list->children().size() == 0)
-			l_id = 1;
-		else{
-			// HACK: Utilizamos reverse_iter, ya que children().end() es una posición más que el último
-			l_riter = m_emulator_list->children().rbegin();
-			l_iter = *l_riter;
-			l_id = (*l_iter)[m_emulator_columns.m_id]  + 1;
-		}
-		p_emulator.setId(l_id);
-	}
-
+	l_id = 1;
 	// Comprobamos si existe un emulador con el mismo identificador o nombre
 	for(l_iter = m_emulator_list->children().begin(); l_iter != m_emulator_list->children().end(); l_iter++){
 		if(((*l_iter)[m_emulator_columns.m_id] == p_emulator.getId()) ||
 			((*l_iter)[m_emulator_columns.m_name] == p_emulator.getName()))
 			return l_iter;
+		// Obtenemos el mayor índice de los emuladores
+		l_id = l_id >= (*l_iter)[m_emulator_columns.m_id] ? l_id : (*l_iter)[m_emulator_columns.m_id];
 	}
+	// Si es un emulador nuevo (Id = 0), establecemos el id adecuado
+	if(p_emulator.getId() == 0)
+		p_emulator.setId(l_id + 1);
 
 	// Añadimos el emulador
 	GELIDE_DEBUG("System " << getName().data() << ": Adding emulator " << p_emulator.getName() << "...");
@@ -427,7 +421,7 @@ Gtk::TreeModel::iterator CSystem::addEmulator(CEmulator& p_emulator){
 				(*l_iter)[m_emulator_columns.m_icon] = Gdk::Pixbuf::create_from_file(p_emulator.getIconFile())->scale_simple(32, 32, Gdk::INTERP_BILINEAR);
 			}
 			catch(const Glib::Exception& l_exception){
-				GELIDE_WARNING("Loading emulator iconr (" << l_exception.what().c_str() << ")");
+				GELIDE_WARNING("Loading emulator icon (" << l_exception.what().c_str() << ")");
 				(*l_iter)[m_emulator_columns.m_icon] = m_manager->getEmulatorDefaultIcon();
 			}
 		//}
@@ -528,8 +522,8 @@ Glib::ustring CSystem::getBackDir(void){
 	return m_back_dir;
 }
 
-Glib::ustring CSystem::getCardDir(void){
-	return m_card_dir;
+Glib::ustring CSystem::getMediaDir(void){
+	return m_media_dir;
 }
 
 unsigned int CSystem::getGames(void){
@@ -565,7 +559,6 @@ unsigned int CSystem::getDatGames(void){
 	return m_dat_games;
 }
 
-
 // Establecer el indice del sistema
 void CSystem::setId(const unsigned int p_id){
 	m_id = p_id;
@@ -618,14 +611,15 @@ void CSystem::setBackDir(const Glib::ustring& p_back_dir){
 	m_back_dir = p_back_dir;
 }
 
-void CSystem::setCardDir(const Glib::ustring& p_card_dir){
-	m_card_dir = p_card_dir;
+void CSystem::setMediaDir(const Glib::ustring& p_media_dir){
+	m_media_dir = p_media_dir;
 }
 
 void CSystem::setEmulatorId(const  unsigned int p_id){
 	m_emulator_id = p_id;
 }
 
+
 // Establecer información del dat
 void CSystem::setDatName(const Glib::ustring& p_name){
 	m_dat_name = p_name;
