@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /*
  * gelide
- * Copyright (C) 2008 Juan Ángel Moreno Fernández
+ * Copyright (C) 2008 - 2011 Juan Ángel Moreno Fernández
  *
  * gelide is free software.
  *
@@ -26,9 +26,11 @@
 #include <gtkmm/image.h>
 #include <giomm/file.h>
 #include "system_manager.hpp"
-#include "cmprodatfile.hpp"
-#include "../gelide-utils.hpp"
-#include "../xml_tools.hpp"
+#include "../utils/utils.hpp"
+#include "../utils/xml_reader.hpp"
+#include "../utils/xml_writer.hpp"
+#include "../utils/tokenizer.hpp"
+
 
 CSystemManager::CSystemManager(void){
 	Gtk::Image l_image;
@@ -65,15 +67,16 @@ Glib::RefPtr<Gdk::Pixbuf> CSystemManager::getEmulatorDefaultIcon(void){
 bool CSystemManager::load(void){
 	std::ifstream l_file;
 	CTokenizer l_tokenizer;
-	CToken l_token;
+	CTokenizer::CToken l_token;
 	CSystem* l_system;
 	bool l_ret = false;
 	bool l_value;
 
 	// Cargamos los sistemas del usuario.
 	GELIDE_DEBUG("Loading systems...");
-	if(l_tokenizer.initFromFile(m_config->getSystemsList())){
-		l_tokenizer.setDelimiters((char *)CSV_SEPARATOR, 1);
+	if(l_tokenizer.initFromFile(utils::getSystemsList())){
+		//l_tokenizer.setDelimiters((char *)CSV_SEPARATOR, 1);
+		l_tokenizer.setDelimiters("\n\x3B", 2);
 		while(l_tokenizer.hasMoreTokens()){
 			// Preparamos el sistema
 			l_system = new CSystem();
@@ -102,9 +105,9 @@ bool CSystemManager::load(void){
 			l_tokenizer.nextToken(l_token);
 			l_system->setBackDir(Glib::strcompress(l_token.getString()));		// Directorio de Backs
 			l_tokenizer.nextToken(l_token);
-			l_system->setCardDir(Glib::strcompress(l_token.getString()));		// Directorio de Cards
+			l_system->setMediaDir(Glib::strcompress(l_token.getString()));		// Directorio de Medias
 			l_tokenizer.nextToken(l_token);
-			l_system->setEmulatorId(l_token.getValue());	// Emulador asignado
+			l_system->setEmulatorId(l_token.getValue());						// Emulador asignado
 			// Información del dat
 			l_tokenizer.nextToken(l_token);
 			l_system->setDatName(Glib::strcompress(l_token.getString()));		// Nombre del dat
@@ -125,7 +128,8 @@ bool CSystemManager::load(void){
 	}
 
 	// Cargamos los sistemas por defecto.
-	m_config->getPrefsImportSystems(l_value);
+	//m_config->getPrefsImportSystems(l_value);
+	m_config->getKey(GELIDE_CFG_PREFERENCES, "import_default_systems", l_value);
 	if(l_value){
 		GELIDE_DEBUG("Loading default systems...");
 		generateDefaultSystems();
@@ -141,7 +145,7 @@ bool CSystemManager::save(void){
 	std::ofstream l_file;
 
 	GELIDE_DEBUG("Saving systems...");
-	l_file.open(m_config->getSystemsList().data());
+	l_file.open(utils::getSystemsList().data());
 	if(l_file.good()){
 		for(l_iter = m_systems.begin(); l_iter != m_systems.end(); l_iter++){
 			l_file << (*l_iter)->getAsString();
@@ -155,68 +159,70 @@ bool CSystemManager::save(void){
 }
 
 bool CSystemManager::importSystems(const Glib::ustring& p_file){
-	CXmlDocument l_xml;
+	CXmlReader l_xml;
 	CXmlNode l_snode;
-	CXmlNode l_cnode;
+	CXmlNode::iterator l_iter, l_iter_child;
 	CSystem* l_system;
 	CEmulator l_emulator;
 	Glib::ustring l_path, l_file;
+	unsigned int l_id;
+	Glib::ustring l_str;
+
 
 	GELIDE_DEBUG("Importing systems...");
-	if(l_xml.load(p_file)){
+	if(l_xml.open(p_file)){
 		// Path  al directorio del listado de importación donde se supone
 		// que estarán los directorios icons y dats
 		l_path = Glib::path_get_dirname(p_file);
 
-		l_snode = l_xml.getRoot();		// <systems>
-		if(l_snode.isValid()){
-			l_snode = l_snode.getChild();	// <system>
-			while(l_snode.isValid()){
-				// Saltamos los no elementos
-				if(!l_snode.isElement()){
-					l_snode = l_snode.getNext();
-					continue;
-				}
+		l_snode = l_xml.getRootElement();		// <systems>
+		if(l_snode.getName() == "systems"){
+			for(l_iter = l_snode.begin(); l_iter != l_snode.end();++l_iter){
 				// Preparamos el sistema y obtenemos la información preliminar
 				l_system = new CSystem();
-				l_system->setEmulatorId(atoi(l_snode.getAttributeValue("emuid").c_str()));				// Emulador asignado
-				l_system->setName(l_snode.getAttributeValue("name"));									// Nombre
-				l_system->setDescription(l_snode.getAttributeValue("description"));						// Descripción
-				if(l_snode.getAttributeValue("iconfile") != "")
-					l_system->setIconFile(l_path + "/" + l_snode.getAttributeValue("iconfile"));		// Fichero de icono
-				if(l_snode.getAttributeValue("datfile") != "")
-					l_system->setDatFile(l_path + "/" + l_snode.getAttributeValue("datfile"));			// Fichero de dat
+				l_iter->getAttribute("emuid", l_id);
+				l_system->setEmulatorId(l_id);						// Emulador asignado
+				l_iter->getAttribute("name", l_str);
+				l_system->setName(l_str);							// Nombre
+				l_iter->getAttribute("description", l_str);
+				l_system->setDescription(l_str);					// Descripción
+				l_iter->getAttribute("iconfile", l_str);
+				if(l_str != "")
+					l_system->setIconFile(Glib::build_filename(l_path,l_str));	// Fichero de icono
+				l_iter->getAttribute("datfile", l_str);
+				if(l_str != "")
+					l_system->setDatFile(Glib::build_filename(l_path,l_str));			// Fichero de dat
 				GELIDE_DEBUG("Importando sistema: " << l_system->getName());
-				// Obtenemos el primer hijo y obtenemos los datos del sistema
-				l_cnode = l_snode.getChild();  //<emulator>
-				while(l_cnode.isValid()){
-					// Saltamos los no elementos
-					if(!l_cnode.isElement()){
-						l_cnode = l_cnode.getNext();
-						continue;
-					}
+				// Obtenemos los datos de los emuladores
+				for(l_iter_child = l_iter->begin(); l_iter_child != l_iter->end(); ++l_iter_child){
 					// Leemos la información del emulador
-					l_emulator.setId(atoi(l_cnode.getAttributeValue("id").c_str()));
-					l_emulator.setName(l_cnode.getAttributeValue("name"));
-					l_emulator.setDescription(l_cnode.getAttributeValue("description"));
-					l_emulator.setVersion(l_cnode.getAttributeValue("version"));
-					l_emulator.setAuthor(l_cnode.getAttributeValue("author"));
-					l_emulator.setHomepage(l_cnode.getAttributeValue("homepage"));
-					l_emulator.setPath(l_cnode.getAttributeValue("bindir"));
-					l_emulator.setParams(l_cnode.getAttributeValue("params"));
-					if(l_cnode.getAttributeValue("iconfile") != "")
-						l_emulator.setIconFile(l_path + "/" + l_cnode.getAttributeValue("iconfile"));
+					l_iter_child->getAttribute("id", l_id);
+					l_emulator.setId(l_id);
+					l_iter_child->getAttribute("name", l_str);
+					l_emulator.setName(l_str);
+					l_iter_child->getAttribute("description", l_str);
+					l_emulator.setDescription(l_str);
+					l_iter_child->getAttribute("version", l_str);
+					l_emulator.setVersion(l_str);
+					l_iter_child->getAttribute("author", l_str);
+					l_emulator.setAuthor(l_str);
+					l_iter_child->getAttribute("homepage", l_str);
+					l_emulator.setHomepage(l_str);
+					l_iter_child->getAttribute("bindir", l_str);
+					l_emulator.setPath(l_str);
+					l_iter_child->getAttribute("params", l_str);
+					l_emulator.setParams(l_str);
+					l_iter_child->getAttribute("iconfile", l_str);
+					if(l_str != "")
+						l_emulator.setIconFile(Glib::build_filename(l_path,l_str));
 					else
 						l_emulator.setIconFile("");
 					GELIDE_DEBUG("Importando emulador: " << l_emulator.getName());
 					// Añadimos el emu al sistema
 					l_system->addEmulator(l_emulator);
-
-					l_cnode = l_cnode.getNext();
 				}
 				// Añadimos el sistema al manager
 				addSystem(*l_system);
-				l_snode = l_snode.getNext();
 			}
 		}
 		return true;
@@ -240,35 +246,35 @@ bool CSystemManager::exportSystems(const Glib::ustring& p_file){
 		return false;
 
 	// Obtenemos la configuración de exportación
-	m_config->getPrefsExportIcons(l_export_icons);
-	m_config->getPrefsExportDats(l_export_dats);
+	//m_config->getPrefsExportIcons(l_export_icons);
+	//m_config->getPrefsExportDats(l_export_dats);
+	m_config->getKey(GELIDE_CFG_PREFERENCES, "export_icons", l_export_icons);
+	m_config->getKey(GELIDE_CFG_PREFERENCES, "export_dats", l_export_dats);
+
 
 	// Path a los directorios de iconos y dats
-	l_icons_path = Glib::path_get_dirname(p_file) + "/" + SYSTEMS_EXPORT_ICONS_DIR;
-	l_dats_path = Glib::path_get_dirname(p_file) + "/" + SYSTEMS_EXPORT_DATS_DIR;
+	l_icons_path = Glib::build_filename(Glib::path_get_dirname(p_file), SYSTEMS_EXPORT_ICONS_DIR);
+	l_dats_path = Glib::build_filename(Glib::path_get_dirname(p_file), SYSTEMS_EXPORT_DATS_DIR);
 
 	// Creamos los directorios si no existen
 	if(l_export_icons){
 		if(!Glib::file_test(l_icons_path, Glib::FILE_TEST_EXISTS)){
-			if(!CUtils::createDir(l_icons_path))
+			if(!utils::createDir(l_icons_path))
 				return false;
 		}
 	}
 	if(l_export_dats){
 		if(!Glib::file_test(l_dats_path, Glib::FILE_TEST_EXISTS)){
-			if(!CUtils::createDir(l_dats_path))
+			if(!utils::createDir(l_dats_path))
 				return false;
 		}
 	}
 
 	GELIDE_DEBUG("Exporting systems...");
-	l_xml.startDocument();
 	l_xml.startElement("systems");
 	for(l_siter = m_systems.begin(); l_siter != m_systems.end(); l_siter++){
 		l_xml.startElement("system");
-		l_str.str("");
-		l_str << (*l_siter)->getEmulatorId();
-		l_xml.writeAttribute("emuid", l_str.str());
+		l_xml.writeAttribute("emuid", (*l_siter)->getEmulatorId());
 		l_xml.writeAttribute("name", (*l_siter)->getName());
 		l_xml.writeAttribute("description", (*l_siter)->getDatDescription());
 		// Comprobamos si se dan las condiciones para la copia del icono
@@ -282,10 +288,10 @@ bool CSystemManager::exportSystems(const Glib::ustring& p_file){
 				l_fname = "";
 			l_str.str("");
 			l_str << "s_" << (*l_siter)->getId() << l_fname;
-			l_xml.writeAttribute("iconfile", (Glib::ustring) SYSTEMS_EXPORT_ICONS_DIR + "/" + l_str.str());
+			l_xml.writeAttribute("iconfile", Glib::build_filename(SYSTEMS_EXPORT_ICONS_DIR, l_str.str()));
 			// Copiamos el fichero
 			l_ifile = Gio::File::create_for_path((*l_siter)->getIconFile());
-			l_ofile = Gio::File::create_for_path(l_icons_path + "/" + l_str.str());
+			l_ofile = Gio::File::create_for_path(Glib::build_filename(l_icons_path, l_str.str()));
 			l_ifile->copy(l_ofile, Gio::FILE_COPY_OVERWRITE);
 		}
 		else
@@ -297,10 +303,10 @@ bool CSystemManager::exportSystems(const Glib::ustring& p_file){
 			l_str.str("");
 			l_str << "s_" << (*l_siter)->getId() << ".dat";
 
-			l_xml.writeAttribute("datfile", (Glib::ustring) SYSTEMS_EXPORT_DATS_DIR + "/" + l_str.str());
+			l_xml.writeAttribute("datfile", Glib::build_filename(SYSTEMS_EXPORT_DATS_DIR, l_str.str()));
 			// Copiamos el fichero
 			l_ifile = Gio::File::create_for_path((*l_siter)->getDatFile());
-			l_ofile = Gio::File::create_for_path(l_dats_path + "/" + l_str.str());
+			l_ofile = Gio::File::create_for_path(Glib::build_filename(l_dats_path, l_str.str()));
 			l_ifile->copy(l_ofile , Gio::FILE_COPY_OVERWRITE);
 		}
 		else
@@ -310,9 +316,7 @@ bool CSystemManager::exportSystems(const Glib::ustring& p_file){
 			l_eiter != (*l_siter)->getEmulatorList()->children().end(); l_eiter++){
 			l_emu = (*l_siter)->getEmulator(l_eiter);
 			l_xml.startElement("emulator");
-			l_str.str("");
-			l_str << l_emu->getId();
-			l_xml.writeAttribute("id", l_str.str());
+			l_xml.writeAttribute("id", l_emu->getId());
 			l_xml.writeAttribute("name", l_emu->getName());
 			l_xml.writeAttribute("description", l_emu->getDescription());
 			l_xml.writeAttribute("version", l_emu->getVersion());
@@ -331,10 +335,10 @@ bool CSystemManager::exportSystems(const Glib::ustring& p_file){
 					l_fname = "";
 				l_str.str("");
 				l_str << "s_" << (*l_siter)->getId()<< "_e_"<< l_emu->getId()<< l_fname;
-				l_xml.writeAttribute("iconfile", (Glib::ustring) SYSTEMS_EXPORT_ICONS_DIR + "/" + l_str.str());
+				l_xml.writeAttribute("iconfile", Glib::build_filename(SYSTEMS_EXPORT_ICONS_DIR, l_str.str()));
 				// Copiamos el fichero
 				l_ifile = Gio::File::create_for_path(l_emu->getIconFile());
-				l_ofile = Gio::File::create_for_path(l_icons_path + "/" + l_str.str());
+				l_ofile = Gio::File::create_for_path(Glib::build_filename(l_icons_path, l_str.str()));
 				l_ifile->copy(l_ofile, Gio::FILE_COPY_OVERWRITE);
 			}
 			else
@@ -345,7 +349,7 @@ bool CSystemManager::exportSystems(const Glib::ustring& p_file){
 		l_xml.endElement();
 	}
 	l_xml.endElement();
-	l_xml.endDocument();
+	l_xml.close();
 	return true;
 }
 
@@ -438,16 +442,8 @@ Gtk::TreeModel::iterator CSystemManager::addSystem(CSystem& p_system){
 	// Comprobamos que tiene un nombre válido
 	if(p_system.getName() == "")
 		return l_tree_iter;
-	// Comprobamos si es un sistema nuevo (Id = 0)
-	if(p_system.getId() == 0){
-		// Establecemos el id como uno más que el último
-		if(m_systems.size() == 0)
-			l_index = 1;
-		else
-			l_index = m_systems.at(m_systems.size()- 1)->getId()  + 1;
-		p_system.setId(l_index);
-	}
 
+	l_index = 1;
 	// Comprobamos si existe un sistema con el mismo identificador o nombre
 	for(l_iter = m_systems.begin(); l_iter != m_systems.end(); l_iter++){
 		if((*l_iter)->getId() == p_system.getId())
@@ -456,8 +452,14 @@ Gtk::TreeModel::iterator CSystemManager::addSystem(CSystem& p_system){
 			(*l_iter)->update(p_system);
 			return l_tree_iter;
 		}
+		// Obtenemos el mayor índice de los sistemas
+		l_index = l_index >= (*l_iter)->getId() ? l_index : (*l_iter)->getId();
 	}
 
+	// Si es un sistema nuevo (Id = 0), establecemos el id adecuado
+	if(p_system.getId() == 0)
+		p_system.setId(l_index + 1);
+
 	GELIDE_DEBUG("Adding system " << p_system.getName().data() << "...");
 	// Establecemos el icono del sistema
 	try{
@@ -469,23 +471,23 @@ Gtk::TreeModel::iterator CSystemManager::addSystem(CSystem& p_system){
 	}
 	// Establecemos su home si no se ha asignado
 	if(p_system.getHomeDir() == "")
-		p_system.setHomeDir(m_config->getGelideDir() + "/" + p_system.getName());
+		p_system.setHomeDir(Glib::build_filename(utils::getGelideDir(), p_system.getName()));
 
 	// Comprobamos su jerarquía de directorios
 	checkSystemDirs(p_system);
 	// Establecemos los directorios por defecto si son necesarios
 	if(p_system.getRomsDir() == "")
-		p_system.setRomsDir(p_system.getHomeDir() + "/" + SYSTEMS_ROMS);
+		p_system.setRomsDir(Glib::build_filename(p_system.getHomeDir(), SYSTEMS_ROMS));
 	if(p_system.getSnapDir() == "")
-		p_system.setSnapDir(p_system.getHomeDir() + "/" + SYSTEMS_IMAGES_SNAP);
+		p_system.setSnapDir(Glib::build_filename(p_system.getHomeDir(),  SYSTEMS_IMAGES_SNAP));
 	if(p_system.getTitleDir() == "")
-		p_system.setTitleDir(p_system.getHomeDir() + "/" + SYSTEMS_IMAGES_TITLE);
+		p_system.setTitleDir(Glib::build_filename(p_system.getHomeDir(), SYSTEMS_IMAGES_TITLE));
 	if(p_system.getFrontDir() == "")
-		p_system.setFrontDir(p_system.getHomeDir() + "/" + SYSTEMS_IMAGES_FRONT);
+		p_system.setFrontDir(Glib::build_filename(p_system.getHomeDir(), SYSTEMS_IMAGES_FRONT));
 	if(p_system.getBackDir() == "")
-		p_system.setBackDir(p_system.getHomeDir() + "/" + SYSTEMS_IMAGES_BACK);
-	if(p_system.getCardDir() == "")
-		p_system.setCardDir(p_system.getHomeDir() + "/" + SYSTEMS_IMAGES_CARD);
+		p_system.setBackDir(Glib::build_filename(p_system.getHomeDir(), SYSTEMS_IMAGES_BACK));
+	if(p_system.getMediaDir() == "")
+		p_system.setMediaDir(Glib::build_filename(p_system.getHomeDir(), SYSTEMS_IMAGES_MEDIA));
 
 	// Añadimos a la lista
 	m_systems.push_back(&p_system);
@@ -526,22 +528,22 @@ void CSystemManager::updateSystem(Gtk::TreeModel::iterator& p_iter, CSystem& p_s
 		*l_system = p_system;
 		// Establecemos su home si no se ha asignado
 		if(l_system->getHomeDir() == "")
-			l_system->setHomeDir(m_config->getGelideDir() + "/" + l_system->getName());
+			l_system->setHomeDir(Glib::build_filename(utils::getGelideDir(), l_system->getName()));
 		// Comprobamos estructura de directorios del sistema
 		checkSystemDirs(*l_system);
 		// Establecemos los directorios por defecto si son necesarios
 		if(l_system->getRomsDir() == "")
-			l_system->setRomsDir(l_system->getHomeDir() + "/" + SYSTEMS_ROMS);
+			l_system->setRomsDir(Glib::build_filename(l_system->getHomeDir(), SYSTEMS_ROMS));
 		if(l_system->getSnapDir() == "")
-			l_system->setSnapDir(l_system->getHomeDir() + "/" + SYSTEMS_IMAGES_SNAP);
+			l_system->setSnapDir(Glib::build_filename(l_system->getHomeDir(), SYSTEMS_IMAGES_SNAP));
 		if(l_system->getTitleDir() == "")
-			l_system->setTitleDir(l_system->getHomeDir() + "/" + SYSTEMS_IMAGES_TITLE);
+			l_system->setTitleDir(Glib::build_filename(l_system->getHomeDir(), SYSTEMS_IMAGES_TITLE));
 		if(l_system->getFrontDir() == "")
-			l_system->setFrontDir(l_system->getHomeDir() + "/" + SYSTEMS_IMAGES_FRONT);
+			l_system->setFrontDir(Glib::build_filename(l_system->getHomeDir(), SYSTEMS_IMAGES_FRONT));
 		if(l_system->getBackDir() == "")
-			l_system->setBackDir(l_system->getHomeDir() + "/" + SYSTEMS_IMAGES_BACK);
-		if(l_system->getCardDir() == "")
-			l_system->setCardDir(l_system->getHomeDir() + "/" + SYSTEMS_IMAGES_CARD);
+			l_system->setBackDir(Glib::build_filename(l_system->getHomeDir(), SYSTEMS_IMAGES_BACK));
+		if(l_system->getMediaDir() == "")
+			l_system->setMediaDir(Glib::build_filename(l_system->getHomeDir(), SYSTEMS_IMAGES_MEDIA));
 		// Actualizamos su entrada en el listmodel
 		(*p_iter)[m_system_columns.m_icon] = l_system->getIcon();
 		(*p_iter)[m_system_columns.m_name] = l_system->getName();
@@ -549,6 +551,96 @@ void CSystemManager::updateSystem(Gtk::TreeModel::iterator& p_iter, CSystem& p_s
 	}
 }
 
+void CSystemManager::moveSystemFirst(Gtk::TreeModel::iterator& p_iter){
+	std::vector<CSystem*>::iterator l_iter;
+	Gtk::TreeModel::iterator l_dest;
+	CSystem* l_tmp;
+
+
+	for(l_iter = m_systems.begin(); l_iter != m_systems.end(); ++l_iter){
+		if((*l_iter)->getId() == (*p_iter)[m_system_columns.m_id]){
+			while(l_iter != m_systems.begin()){
+				l_tmp = (*(l_iter - 1));
+				*(l_iter-1) = *l_iter;
+				*l_iter = l_tmp;
+				--l_iter;
+			}
+
+			// Intercambiamos las filas en el listado de columnas
+			l_dest = m_system_list->children().begin();
+			m_system_list->move(p_iter, l_dest);
+
+			return;
+		}
+	}
+}
+
+void CSystemManager::moveSystemUp(Gtk::TreeModel::iterator& p_iter){
+	std::vector<CSystem*>::iterator l_iter;
+	Gtk::TreeModel::iterator l_orig;
+	CSystem* l_tmp;
+
+	// Buscamos el systema a mover
+	for(l_iter = m_systems.begin(); l_iter != m_systems.end(); ++l_iter){
+		if((*l_iter)->getId() == (*p_iter)[m_system_columns.m_id]){
+			// Movemos arriba en el vector de sistemas
+			l_tmp = (*(l_iter - 1));
+			*(l_iter-1) = *l_iter;
+			*l_iter = l_tmp;
+
+			// Movemos arriba en el modelo de sistemas
+			l_orig = p_iter--;
+			m_system_list->move(l_orig, p_iter);
+
+			return;
+		}
+	}
+}
+
+void CSystemManager::moveSystemDown(Gtk::TreeModel::iterator& p_iter){
+	std::vector<CSystem*>::iterator l_iter;
+	Gtk::TreeModel::iterator l_orig;
+	CSystem* l_tmp;
+
+	for(l_iter = m_systems.begin(); l_iter != m_systems.end(); ++l_iter){
+		if((*l_iter)->getId() == (*p_iter)[m_system_columns.m_id]){
+			l_tmp = *(l_iter + 1);
+			*(l_iter + 1) = *l_iter;
+			*l_iter = l_tmp;
+
+			// Movemos arriba en el modelo de sistemas
+			l_orig = p_iter++;
+			++p_iter;
+			m_system_list->move(l_orig, p_iter);
+			return;
+		}
+	}
+}
+
+void CSystemManager::moveSystemLast(Gtk::TreeModel::iterator& p_iter){
+	std::vector<CSystem*>::iterator l_iter;
+	Gtk::TreeModel::iterator l_dest;
+	CSystem* l_tmp;
+
+
+	for(l_iter = m_systems.begin(); l_iter != m_systems.end(); ++l_iter){
+		if((*l_iter)->getId() == (*p_iter)[m_system_columns.m_id]){
+			while((l_iter + 1) != m_systems.end()){
+				l_tmp = (*(l_iter + 1));
+				*(l_iter+1) = *l_iter;
+				*l_iter = l_tmp;
+				++l_iter;
+			}
+			// Intercambiamos las filas en el listado de columnas
+			l_dest = m_system_list->children().end();
+			m_system_list->move(p_iter, l_dest);
+
+			return;
+		}
+	}
+}
+
+
 unsigned int CSystemManager::getGames(void){
 	std::vector<CSystem*>::iterator l_iter;
 	unsigned int l_ret;
@@ -567,29 +659,29 @@ bool CSystemManager::checkSystemDirs(CSystem& p_system){
 	// Comprobamos su directorio home y si existe asumimos que toda la
 	// jerarquía se creo con anterioridad
 	if(!Glib::file_test(p_system.getHomeDir(),	Glib::FILE_TEST_EXISTS)){
-		if(!CUtils::createDir(p_system.getHomeDir()))
+		if(!utils::createDir(p_system.getHomeDir()))
 			return false;
 		// Debemos crear los directorios internos del sistema
 		// Directorio de imágenes
-		if(!CUtils::createDir(p_system.getHomeDir() + "/" + SYSTEMS_IMAGES))
+		if(!utils::createDir(Glib::build_filename(p_system.getHomeDir(), SYSTEMS_IMAGES)))
 			return false;
 		// Directorio de roms
-		if(!CUtils::createDir(p_system.getHomeDir() + "/" + SYSTEMS_ROMS))
+		if(!utils::createDir(Glib::build_filename(p_system.getHomeDir(), SYSTEMS_ROMS)))
 			return false;
 		// Directorio de snapshot
-		if(!CUtils::createDir(p_system.getHomeDir() + "/" + SYSTEMS_IMAGES_SNAP))
+		if(!utils::createDir(Glib::build_filename(p_system.getHomeDir(), SYSTEMS_IMAGES_SNAP)))
 			return false;
 		// Directorio de titles
-		if(!CUtils::createDir(p_system.getHomeDir() + "/" + SYSTEMS_IMAGES_TITLE))
+		if(!utils::createDir(Glib::build_filename(p_system.getHomeDir(), SYSTEMS_IMAGES_TITLE)))
 			return false;
 		// Directorio de fronts
-		if(!CUtils::createDir(p_system.getHomeDir() + "/" + SYSTEMS_IMAGES_FRONT))
+		if(!utils::createDir(Glib::build_filename(p_system.getHomeDir(), SYSTEMS_IMAGES_FRONT)))
 			return false;
 		// Directorio de back
-		if(!CUtils::createDir(p_system.getHomeDir() + "/" + SYSTEMS_IMAGES_BACK))
+		if(!utils::createDir(Glib::build_filename(p_system.getHomeDir(), SYSTEMS_IMAGES_BACK)))
 			return false;
-		// Directorio de cardtridge
-		if(!CUtils::createDir(p_system.getHomeDir() + "/" + SYSTEMS_IMAGES_CARD))
+		// Directorio de Soportes
+		if(!utils::createDir(Glib::build_filename(p_system.getHomeDir(), SYSTEMS_IMAGES_MEDIA)))
 			return false;
 	}
 	return true;
