@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /*
  * gelide
- * Copyright (C) 2008 Juan Ángel Moreno Fernández
+ * Copyright (C) 2008 - 2011 Juan Ángel Moreno Fernández
  *
  * gelide is free software.
  *
@@ -23,7 +23,7 @@
 #define _DIALOG_GAME_PROPERTIES_HPP_
 
 #include <gtkmm/dialog.h>
-#include "../gelide-i18n.hpp"
+#include "../gelide_i18n.hpp"
 
 using namespace std;
 
