@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /*
  * gelide
- * Copyright (C) 2008 Juan Ángel Moreno Fernández
+ * Copyright (C) 2008 - 2011 Juan Ángel Moreno Fernández
  *
  * gelide is free software.
  *
@@ -89,64 +89,67 @@ CGelideUI::CGelideUI(void):
 }
 
 CGelideUI::~CGelideUI(){
-	m_smanager->save();
-	saveConfig();
+	//m_smanager->save();
+	//saveConfig();
 }
 
 void CGelideUI::loadConfig(void){
-	int l_x, l_y, l_t;
-	unsigned int l_z;
+	int l_x, l_y;
 	bool l_val;
 	Glib::RefPtr<Gtk::ToggleAction> l_toggleaction;
 	Glib::RefPtr<Gtk::RadioAction> l_radioaction;
 	Gtk::TreeModel::iterator l_iter;
 	Glib::ustring l_str;
-	CSystem* l_system;
 
 	GELIDE_DEBUG("Loading configuration...");
 
-	// Obtenemos las dimensiones almacenadas
-	m_config->getUISize(l_x, l_y);
-	// Comprobamos que son válidas
-	if((l_x!= -1) && (l_y != -1))
-		this->set_default_size(l_x, l_y);
-
-	// Obtenemos la posición almacenada
-	m_config->getUIPos(l_x, l_y);
-	if((l_x!= -1) && (l_y != -1))
-		this->move(l_x, l_y);
-
 	// Cargamos el modo fullscreen
-	m_config->getUIFullScreen(l_val);
+	m_config->getKey(GELIDE_CFG_UI, "fullscreen_mode", l_val);
 	l_toggleaction = Glib::RefPtr< Gtk::ToggleAction >::cast_dynamic( m_action_group->get_action("FullScreen"));
 	l_toggleaction->set_active(l_val);
 
+	if(!l_val){
+		// Obtenemos las dimensiones almacenadas
+		m_config->getKey(GELIDE_CFG_UI, "ui_width", l_x);
+		m_config->getKey(GELIDE_CFG_UI, "ui_height", l_y);
+		// Comprobamos que son válidas
+		if((l_x!= -1) && (l_y != -1))
+			this->set_default_size(l_x, l_y);
+
+		// Obtenemos la posición almacenada
+		m_config->getKey(GELIDE_CFG_UI, "ui_x", l_x);
+		m_config->getKey(GELIDE_CFG_UI, "ui_y", l_y);
+		if((l_x!= -1) && (l_y != -1))
+			this->move(l_x, l_y);
+	}
 	// Obtenemos el estado de la barra de herramientas
-	m_config->getUIToolbarVisible(l_val);
+	m_config->getKey(GELIDE_CFG_UI, "tool_bar_visible", l_val);
 	l_toggleaction = Glib::RefPtr< Gtk::ToggleAction >::cast_dynamic( m_action_group->get_action("ToolsBar"));
 	l_toggleaction->set_active(l_val);
 
 	// Obtenemos las propiedades del árbol de filtros
-	m_config->getUIFiltersVisible(l_val);
-	m_config->getUIFiltersWidth(l_x);
+	m_config->getKey(GELIDE_CFG_UI, "filters_visible", l_val);
+	m_config->getKey(GELIDE_CFG_UI, "filters_width", l_x);
 	if(l_x!= -1)
 		m_hpaned_filters.set_position(l_x);
 	l_toggleaction = Glib::RefPtr< Gtk::ToggleAction >::cast_dynamic( m_action_group->get_action("Filters"));
 	l_toggleaction->set_active(l_val);
 
 	// Obtenemos las dimensiones de los examinadores (izquierdo y superior)
-	m_config->getUIBrowserLeftSize(l_x, l_y);
+	m_config->getKey(GELIDE_CFG_UI, "browser_left_width", l_x);
+	m_config->getKey(GELIDE_CFG_UI, "browser_left_height", l_y);
 	if((l_x!= -1) && (l_y != -1)){
 		m_hpaned_lbrowser.set_position(l_x);
 		m_vpaned_browser.set_position(l_y);
 	}
-	m_config->getUIBrowserTopSize(l_x, l_y);
+	m_config->getKey(GELIDE_CFG_UI, "browser_top_width", l_x);
+	m_config->getKey(GELIDE_CFG_UI, "browser_top_height", l_y);
 	if((l_x!= -1) && (l_y != -1)){
 		m_hpaned_browser.set_position(l_x);
 		m_vpaned_games.set_position(l_y);
 	}
 	// Obtenemos el modo de examinador
-	m_config->getUIBrowserMode(m_browser_mode);
+	m_config->getKey(GELIDE_CFG_UI, "browser_mode", m_browser_mode);
 	if(m_browser_mode < 0)
 		m_browser_mode = 0;
 	// Activamos el examinador superior
@@ -160,38 +163,30 @@ void CGelideUI::loadConfig(void){
 		// El examinador izquierdo es el examinador por defecto, así que no activamos nada
 		m_hpaned_browser.hide();
 	// Obtenemos la visibilidad del browser
-	m_config->getUIBrowserVisible(l_val);
+	m_config->getKey(GELIDE_CFG_UI, "browser_visible", l_val);
 	l_toggleaction = Glib::RefPtr< Gtk::ToggleAction >::cast_dynamic( m_action_group->get_action("Browser"));
 	l_toggleaction->set_active(l_val);
 
 	// Cargamos el estado del panel de información
-	m_config->getUIInfoPannelWidth(l_x);
+	m_config->getKey(GELIDE_CFG_UI, "info_pannel_widht", l_x);
 	if(l_x!= -1)
 		m_hpaned_info.set_position(l_x);
-	m_config->getUIInfoPannelVisible(l_val);
+	m_config->getKey(GELIDE_CFG_UI, "info_pannel_visible", l_val);
 	l_toggleaction = Glib::RefPtr< Gtk::ToggleAction >::cast_dynamic( m_action_group->get_action("Info"));
 	l_toggleaction->set_active(l_val);
 
-	// Obtenemos el estado de la barra de herramientas
-	m_config->getUIStatusBarVisible(l_val);
+	// Obtenemos el estado de la barra de estado
+	m_config->getKey(GELIDE_CFG_UI, "status_bar_visible", l_val);
 	l_toggleaction = Glib::RefPtr< Gtk::ToggleAction >::cast_dynamic( m_action_group->get_action("StatusBar"));
 	l_toggleaction->set_active(l_val);
 
 	// Cargamos el sistema seleccionado
-	m_config->getUISelectedSystem(l_x);
+	m_config->getKey(GELIDE_CFG_UI, "selected_system", l_x);
 	if(l_x!= -1){
 		l_iter = m_smanager->getSystem(l_x);
 		if(l_iter)
 			m_treeview_systems.setSelected(l_iter);
 	}
-
-	// Obtenemos el filtro
-	m_treeview_filters.getFilter(&l_x, &l_z);
-	onFilterChanged(l_x, l_z);
-
-	// Cargamos el estado del buscador
-	//m_config->getUISearchString(l_str);
-	//m_entry_search.set_text(l_str);
 }
 
 void CGelideUI::saveConfig(void){
@@ -201,62 +196,74 @@ void CGelideUI::saveConfig(void){
 	Gtk::TreeModel::iterator l_iter;
 
 	GELIDE_DEBUG("Saving configuration...");
-	// Guardamos las dimensiones de la ventana
-	this->get_size(l_x, l_y);
-	m_config->setUISize(l_x, l_y);
-
-	// Guardamos la posición de la ventana
-	this->get_position(l_x, l_y);
-	m_config->setUIPos(l_x, l_y);
-
 	// Guardamos el modo fullscreen
 	l_toggleaction = Glib::RefPtr< Gtk::ToggleAction >::cast_dynamic( m_action_group->get_action("FullScreen"));
-	m_config->setUIFullScreen(l_toggleaction->get_active());
+	m_config->setKey(GELIDE_CFG_UI, "fullscreen_mode", l_toggleaction->get_active());
+
+	// Guardamos las dimensiones y posición de la ventana principal si no
+	// estamos en modo fullscreen
+	if(!l_toggleaction->get_active()){
+		// Dimensiones de la ventana
+		this->get_size(l_x, l_y);
+		m_config->setKey(GELIDE_CFG_UI, "ui_width", l_x);
+		m_config->setKey(GELIDE_CFG_UI, "ui_height", l_y);
+
+		// Posición la posición de la ventana
+		this->get_position(l_x, l_y);
+		m_config->setKey(GELIDE_CFG_UI, "ui_x", l_x);
+		m_config->setKey(GELIDE_CFG_UI, "ui_y", l_y);
+	}
 
 	// Guardamos el estado de la barra de herramientas
-	m_config->setUIToolbarVisible(m_toolbar->is_visible());
+	m_config->setKey(GELIDE_CFG_UI, "tool_bar_visible", m_toolbar->is_visible());
 
 	// Guardamos el estado de los filtros
-	m_config->setUIFiltersVisible(m_vbox_filters.is_visible());
+	m_config->setKey(GELIDE_CFG_UI, "filters_visible", m_vbox_filters.is_visible());
 	l_toggleaction = Glib::RefPtr< Gtk::ToggleAction >::cast_dynamic( m_action_group->get_action("Filters"));
 	if(l_toggleaction->get_active())
-		m_config->setUIFiltersWidth(m_hpaned_filters.get_position());
-
-	// Guardamos el estado del buscador
-	// m_config->setUISearchString(m_entry_search.get_text());
+		m_config->setKey(GELIDE_CFG_UI, "filters_width", m_hpaned_filters.get_position());
 
 	// Guardamos el estado del browser
 	l_toggleaction = Glib::RefPtr< Gtk::ToggleAction >::cast_dynamic( m_action_group->get_action("Browser"));
 	if(l_toggleaction->get_active()){
 		if(m_browser_mode){
 			// Visible el examinador superior guardamos su estado
-			m_config->setUIBrowserTopSize(m_hpaned_browser.get_position(), m_vpaned_games.get_position());
+			m_config->setKey(GELIDE_CFG_UI, "browser_top_width", m_hpaned_browser.get_position());
+			m_config->setKey(GELIDE_CFG_UI, "browser_top_height", m_vpaned_games.get_position());
 		}
 		else{
 			// Visible el examinador izquierdo guardamos su estado
-			m_config->setUIBrowserLeftSize(m_hpaned_lbrowser.get_position(), m_vpaned_browser.get_position());
+			m_config->setKey(GELIDE_CFG_UI, "browser_left_width", m_hpaned_lbrowser.get_position());
+			m_config->setKey(GELIDE_CFG_UI, "browser_left_height", m_vpaned_browser.get_position());
 		}
 	}
-	m_config->setUIBrowserVisible(l_toggleaction->get_active());
-	m_config->setUIBrowserMode(m_browser_mode);
+	m_config->setKey(GELIDE_CFG_UI, "browser_visible", l_toggleaction->get_active());
+	m_config->setKey(GELIDE_CFG_UI, "browser_mode", m_browser_mode);
 
 	// Guardamos el estado del panel de información
-	m_config->setUIInfoPannelVisible(m_info_pannel.is_visible());
+	m_config->setKey(GELIDE_CFG_UI, "info_pannel_visible", m_info_pannel.is_visible());
 	l_toggleaction = Glib::RefPtr< Gtk::ToggleAction >::cast_dynamic( m_action_group->get_action("Info"));
 	if(l_toggleaction->get_active())
-		m_config->setUIInfoPannelWidth(m_hpaned_info.get_position());
+		m_config->setKey(GELIDE_CFG_UI, "info_pannel_widht", m_hpaned_info.get_position());
 
 	// Guardamos el estado de la barra de estado
-	m_config->setUIStatusBarVisible(m_statusbar.is_visible());
+	m_config->setKey(GELIDE_CFG_UI, "status_bar_visible", m_statusbar.is_visible());
 
 	// Guardamos el sistema seleccionado
 	l_iter = m_treeview_systems.getSelected();
 	l_z = 0;
 	if(l_iter)
 		l_z = m_smanager->getSystem(l_iter)->getId();
-	m_config->setUISelectedSystem(l_z);
+	m_config->setKey(GELIDE_CFG_UI, "selected_system", l_z);
 }
 
+bool CGelideUI::on_delete_event(GdkEventAny *p_event){
+	// Llamamos a File->Quit para que realice las tareas adecuadas
+	onActionFileQuit();
+	return false;
+}
+
+
 void CGelideUI::initActions(void){
 
 	// Creamos las acciones
@@ -508,7 +515,7 @@ void CGelideUI::initBody(void){
 	m_hpaned_info.pack1(m_vbox_center, true, false);
 	m_vbox_center.set_border_width(2);
 	m_vbox_center.set_spacing(2);
-	m_hpaned_info.pack2(m_info_pannel, true, true);
+	m_hpaned_info.pack2(m_info_pannel, true, false);
 	m_info_pannel.set_border_width(2);
 	m_vbox_center.pack_start(m_hbox_search, Gtk::PACK_SHRINK);
 	m_vbox_center.pack_start(m_hpaned_lbrowser);
