@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /*
  * gelide
- * Copyright (C) 2008 Juan Ángel Moreno Fernández
+ * Copyright (C) 2008 - 2011 Juan Ángel Moreno Fernández
  *
  * gelide is free software.
  *
@@ -22,7 +22,7 @@
 #include "info_pannel.hpp"
 #include <gtkmm/stock.h>
 #include <gtkmm/icontheme.h>
-#include "../gelide-utils.hpp"
+#include "../utils/utils.hpp"
 #include <sstream>
 
 CInfoPannel::CInfoPannel(void):
@@ -154,16 +154,12 @@ void CInfoPannel::clear(void){
 	m_label_manufacturer_value.set_label("");
 	m_label_year_value.set_label("");
 	m_label_crc_value.set_label("");
-	//m_image_snapshot.set(m_default);
-	//m_image_tittle.set(m_default);
-	//m_image_front.set(m_default);
-	//m_image_back.set(m_default);
-	//m_image_cartridge.set(m_default);
+
 	m_pixbuf_snapshot = m_default->copy();
 	m_pixbuf_tittle = m_default->copy();
 	m_pixbuf_front = m_default->copy();
 	m_pixbuf_back = m_default->copy();
-	m_pixbuf_cartridge = m_default->copy();
+	m_pixbuf_media = m_default->copy();
 
 	m_image_system.set(m_pixbuf_system);
 	m_label_system_name.set_label("");
@@ -202,30 +198,30 @@ void CInfoPannel::updateImages(CSystem* p_system, CGame* p_game){
 			l_path = m_system->getBackDir();
 			break;
 		case 4:
-			l_pixbuf = &m_pixbuf_cartridge;
-			l_path = m_system->getCardDir();
+			l_pixbuf = &m_pixbuf_media;
+			l_path = m_system->getMediaDir();
 			break;
 		}
 		l_find = false;
 		for(l_ind = 0; l_ind < 8; l_ind++ ){
 			// comprobamos nombre.ext
-			if(Glib::file_test(l_path + "/" + p_game->getName() + "." + l_exts[l_ind], Glib::FILE_TEST_EXISTS)){
-				(*l_pixbuf) = Gdk::Pixbuf::create_from_file(l_path + "/" + p_game->getName() + "." + l_exts[l_ind]);
+			if(Glib::file_test(Glib::build_filename(l_path, p_game->getName() + "." + l_exts[l_ind]), Glib::FILE_TEST_EXISTS)){
+				(*l_pixbuf) = Gdk::Pixbuf::create_from_file(Glib::build_filename(l_path, p_game->getName() + "." + l_exts[l_ind]));
 				//l_image->set(l_path + "/" + p_game->getName() + "." + l_exts[l_ind]);
 				l_find = true;
 				break;
 			}
 			// comprobamos crc.ext
-			else if(Glib::file_test(l_path + "/" + p_game->getRomCrc().lowercase() + "." + l_exts[l_ind], Glib::FILE_TEST_EXISTS)){
+			else if(Glib::file_test(Glib::build_filename(l_path, p_game->getRomCrc().lowercase() + "." + l_exts[l_ind]), Glib::FILE_TEST_EXISTS)){
 				//l_image->set(l_path + "/" + p_game->getRomCrc().lowercase() + "." + l_exts[l_ind]);
-				(*l_pixbuf) = Gdk::Pixbuf::create_from_file(l_path + "/" + p_game->getRomCrc().lowercase() + "." + l_exts[l_ind]);
+				(*l_pixbuf) = Gdk::Pixbuf::create_from_file(Glib::build_filename(l_path, p_game->getRomCrc().lowercase() + "." + l_exts[l_ind]));
 				l_find = true;
 				break;
 			}
 			// comprobamos CRC.ext
-			else if(Glib::file_test(l_path + "/" + p_game->getRomCrc().uppercase() + "." + l_exts[l_ind], Glib::FILE_TEST_EXISTS)){
+			else if(Glib::file_test(Glib::build_filename(l_path,p_game->getRomCrc().uppercase() + "." + l_exts[l_ind]), Glib::FILE_TEST_EXISTS)){
 				//l_image->set(l_path + "/" + p_game->getRomCrc().uppercase() + "." + l_exts[l_ind]);
-				(*l_pixbuf) = Gdk::Pixbuf::create_from_file(l_path + "/" + p_game->getRomCrc().uppercase() + "." + l_exts[l_ind]);
+				(*l_pixbuf) = Gdk::Pixbuf::create_from_file(Glib::build_filename(l_path, p_game->getRomCrc().uppercase() + "." + l_exts[l_ind]));
 				l_find = true;
 				break;
 			}
@@ -245,8 +241,9 @@ void CInfoPannel::on_size_allocate(Gtk::Allocation & p_allocation){
     Glib::RefPtr<Gdk::Pixbuf> l_pixbuf;
     Gtk::Image* l_image = NULL;
 
-    if(!m_sized){
+    Gtk::VBox::on_size_allocate(p_allocation);
 
+   if(!m_sized){
 		// Seleccionamos la imagen dependiendo del pannel
 		switch(m_notebook_images.get_current_page()){
 		case 0:
@@ -266,8 +263,8 @@ void CInfoPannel::on_size_allocate(Gtk::Allocation & p_allocation){
 			l_image =  &m_image_back;
 			break;
 		case 4:
-			l_pixbuf = m_pixbuf_cartridge;
-			l_image =  &m_image_cartridge;
+			l_pixbuf = m_pixbuf_media;
+			l_image =  &m_image_media;
 			break;
 		}
 		// Tamaño total que tenemos para la imagen
@@ -316,26 +313,29 @@ void CInfoPannel::on_size_allocate(Gtk::Allocation & p_allocation){
     	//GELIDE_DEBUG("Nw " << l_nwidth << " nh " <<l_nheight);
     	//GELIDE_DEBUG("Bw " << m_notebook_images.get_width() << " Bh " << m_notebook_images.get_height());
 
+    	// Al establecer la imagen se provoca que se entre de nuevo en el método
+    	// con m_sized controlamos que no se vuelva a recalcular en la siguiente
+    	// entrada
 		l_image->set(l_pixbuf->scale_simple(l_nwidth, l_nheight, Gdk::INTERP_BILINEAR));
+		m_sized = true;
     }
     else
-    	Gtk::VBox::on_size_allocate(p_allocation);
-
-    m_sized = !m_sized;
+    	m_sized = false;
 }
 
 void CInfoPannel::loadConfig(void){
 	int l_pannel;
 
 	// Obtenemos la posición almacenada
-	m_config->getUIInfoPannel(l_pannel);
-
+	//m_config->getUIInfoPannel(l_pannel);
+	m_config->getKey(GELIDE_CFG_UI, "info_pannel_selected", l_pannel);
 	if(l_pannel != -1)
 		m_notebook_images.set_current_page(l_pannel);
 }
 
 void CInfoPannel::saveConfig(void){
-	m_config->setUIInfoPannel(m_notebook_images.get_current_page());
+	//m_config->setUIInfoPannel(m_notebook_images.get_current_page());
+	m_config->setKey(GELIDE_CFG_UI, "info_pannel_selected", m_notebook_images.get_current_page());
 }
 
 void CInfoPannel::initFlagsIcons(void){
@@ -416,7 +416,7 @@ void CInfoPannel::initImages(void){
 	m_notebook_images.append_page(m_image_tittle, _("Title"));
 	m_notebook_images.append_page(m_image_front, _("Front"));
 	m_notebook_images.append_page(m_image_back, _("Back"));
-	m_notebook_images.append_page(m_image_cartridge, _("Cartridge"));
+	m_notebook_images.append_page(m_image_media, _("Media"));
 
 	//m_default = Gdk::Pixbuf::create_from_file(GELIDE_DEFAULT_IMAGE);
 	m_default = Gtk::IconTheme::get_default()->load_icon("gtk-missing-image", 200, Gtk::ICON_LOOKUP_USE_BUILTIN);
@@ -425,7 +425,7 @@ void CInfoPannel::initImages(void){
 	m_pixbuf_tittle = m_default->copy();
 	m_pixbuf_front = m_default->copy();
 	m_pixbuf_back = m_default->copy();
-	m_pixbuf_cartridge = m_default->copy();
+	m_pixbuf_media = m_default->copy();
 
 }
 void CInfoPannel::initSystem(void){
@@ -435,7 +435,7 @@ void CInfoPannel::initSystem(void){
 	m_label_system_name.set_ellipsize(Pango::ELLIPSIZE_END);
 	m_label_system_description.set_alignment(0, 0);
 	m_label_system_description.set_ellipsize(Pango::ELLIPSIZE_END);
-	m_pixbuf_system = CUtils::createNegativePixbuf(m_smanager->getSystemDefaultIcon());
+	m_pixbuf_system = utils::createNegativePixbuf(m_smanager->getSystemDefaultIcon());
 	m_image_system.set(m_pixbuf_system);
 	m_image_system.set_padding(10,10);
 
@@ -459,7 +459,7 @@ void CInfoPannel::initEmulator(void){
 	m_label_emulator_name.set_ellipsize(Pango::ELLIPSIZE_END);
 	m_label_emulator_description.set_alignment(0, 0);
 	m_label_emulator_description.set_ellipsize(Pango::ELLIPSIZE_END);
-	m_pixbuf_emulator = CUtils::createNegativePixbuf(m_smanager->getEmulatorDefaultIcon());
+	m_pixbuf_emulator = utils::createNegativePixbuf(m_smanager->getEmulatorDefaultIcon());
 	m_image_emulator.set(m_pixbuf_emulator);
 	m_image_emulator.set_padding(10,10);
 
