@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /*
  * gelide
- * Copyright (C) 2008 Juan Ángel Moreno Fernández
+ * Copyright (C) 2008 - 2011 Juan Ángel Moreno Fernández
  *
  * gelide is free software.
  *
@@ -24,8 +24,8 @@
 #include "treeview_games.hpp"
 #include "gelide_ui.hpp"
 #include "dialog_emulator_launcher.hpp"
-#include "../tokenizer.hpp"
-#include "../gelide-utils.hpp"
+#include "../utils/tokenizer.hpp"
+#include "../utils/utils.hpp"
 
 
 CTreeViewGames::CTreeViewGames(void):
@@ -44,8 +44,8 @@ CTreeViewGames::CTreeViewGames(void):
 
 	m_filter_type = 0;
 	m_filter_value = 0;
-	m_filter_str = "";
-	m_apply_filter_str = false;
+	//m_filter_str = "";
+	m_apply_filter_regex = false;
 
 	initFlagsIcons();
 	initActions();
@@ -295,7 +295,10 @@ void CTreeViewGames::loadConfig(void){
 	int l_ind, l_sort_type;
 
 	// Obtenemos los valores de visibilidad, y anchuras y orden
-	m_config->getUIColumns(l_visibility, l_widths, l_order);
+	//m_config->getUIColumns(l_visibility, l_widths, l_order);
+	m_config->getKey(GELIDE_CFG_UI, "columns_visibility", l_visibility);
+	m_config->getKey(GELIDE_CFG_UI, "columns_widths", l_widths);
+	m_config->getKey(GELIDE_CFG_UI, "columns_order", l_order);
 
 	// Comprobamos si la configuración tiene todos los datos
 	if(!l_visibility.size() || !l_widths.size() || !l_order.size())
@@ -318,15 +321,17 @@ void CTreeViewGames::loadConfig(void){
 	}
 
 	// Obtenemos la columna de ordenación y su tipo de orden
-	m_config->getUISortColumn(m_sort_column, l_sort_type);
+	//m_config->getUISortColumn(m_sort_column, l_sort_type);
+	m_config->getKey(GELIDE_CFG_UI, "sort_column", m_sort_column);
+	m_config->getKey(GELIDE_CFG_UI, "sort_type", l_sort_type);
 	m_sort_type = l_sort_type == 0 ? Gtk::SORT_ASCENDING : Gtk::SORT_DESCENDING;
 
 }
 
 void CTreeViewGames::saveConfig(void){
-	std::list<bool> l_visibility;
-	std::list<int> l_widths;
-	std::list<int> l_order;
+	std::vector<bool> l_visibility;
+	std::vector<int> l_widths;
+	std::vector<int> l_order;
 	std::list<Gtk::TreeViewColumn*> l_columns;
 	std::list<Gtk::TreeViewColumn*>::iterator l_iter;
 	int l_ind;
@@ -349,13 +354,16 @@ void CTreeViewGames::saveConfig(void){
 		}
 	}
 
-	m_config->setUIColumns(l_visibility, l_widths, l_order);
-
+	//m_config->setUIColumns(l_visibility, l_widths, l_order);
+	m_config->setKey(GELIDE_CFG_UI, "columns_visibility", l_visibility);
+	m_config->setKey(GELIDE_CFG_UI, "columns_widths", l_widths);
+	m_config->setKey(GELIDE_CFG_UI, "columns_order", l_order);
 	// Obtenemos la columna de ordenación y su tipo de orden
 	if(m_sort_list)
 		m_sort_list->get_sort_column_id(m_sort_column, m_sort_type);
-	m_config->setUISortColumn(m_sort_column, m_sort_type == Gtk::SORT_ASCENDING ? 0 : 1);
-
+	//m_config->setUISortColumn(m_sort_column, m_sort_type == Gtk::SORT_ASCENDING ? 0 : 1);
+	m_config->setKey(GELIDE_CFG_UI, "sort_column", m_sort_column);
+	m_config->setKey(GELIDE_CFG_UI, "sort_type", m_sort_type);
 }
 
 unsigned int CTreeViewGames::getGames(void){
@@ -373,8 +381,34 @@ void CTreeViewGames::setFilter(const int p_type, const unsigned int p_value){
 }
 
 void CTreeViewGames::setNameFilter(Glib::ustring p_str){
-	m_filter_str = p_str;
-	m_apply_filter_str = (p_str != "");
+	int l_ind;
+
+	// La aplicación del filtro dependerá de esta variable
+	m_apply_filter_regex = (p_str != "");
+
+	// Crearemos la expresión regular solo si es necesario
+	if(m_apply_filter_regex){
+		// Escapamos caracteres especiales en la cadena y añadimos marcador de inicio
+		p_str = "^" + Glib::Regex::escape_string(p_str);
+		// Restauramos las apariciones de * para permitir la sustitución de 0 o
+		// más caracteres
+		l_ind = p_str.find("\\*");
+		while(l_ind > -1){
+			p_str = p_str.replace(l_ind, 2, ".*");
+			l_ind = p_str.find("\\*", l_ind + 1);
+		}
+		// Restauramos las apariciones de ? para permitir la sustitución de 0 o
+		// 1 caracter
+		l_ind = p_str.find("\\?");
+		while(l_ind > -1){
+			p_str = p_str.replace(l_ind, 2, ".?");
+			l_ind = p_str.find("\\?", l_ind + 1);
+		}
+
+		// Creamos la expresión regular para el filtrado por nombre
+		m_filter_regex = Glib::Regex::create(p_str, Glib::REGEX_CASELESS|Glib::REGEX_OPTIMIZE);
+	}
+
 	m_filter_list->refilter();
 }
 
@@ -483,11 +517,11 @@ bool CTreeViewGames::visibleFunction(const Gtk::TreeModel::const_iterator& p_ite
 	default:
 		l_ret = 1;
 	}
-	if((!l_ret) ||  (!m_apply_filter_str))
+	if((!l_ret) ||  (!m_apply_filter_regex))
 		return l_ret;
 	else{
-		l_name = (*p_iter)[m_columns.m_name];
-		return (l_name.compare(0, m_filter_str.size(), m_filter_str) == 0);
+		l_name = (*p_iter)[m_columns.m_description];
+		return (m_filter_regex->match(l_name));
 	}
 }
 
